import QueryString from 'querystring';
import { http, prefix } from '../utils/http-util';

const URL_PREFIX = prefix();
const { GET } = http;

/**
 * 调用get接口并dispatch
 * @param service 接口地址
 * @param params 参数，以{对象}形式
 * @param type
 * @param typeData
 * @returns {Function}
 */
const getDispatch = (service = '', params = null, type = '', typeData = {}) => async (dispatch) => {
  dispatch({
    type: type.LOADING,
    loading: true,
    ...typeData,
  });

  const url = params ? `${URL_PREFIX}${service}?${QueryString.stringify(params)}` : `${URL_PREFIX}${service}`;
  try {
    const data = await GET(url);
    dispatch({
      type: type.LOADING,
      loading: false,
      ...typeData,
    });
    dispatch({
      type: type.SUCCESS,
      data,
      ...typeData,
    });
    return data;
  } catch (e) {
    dispatch({
      type: type.LOADING,
      loading: false,
      ...typeData,
    });
  }
};

/**
 * 仅调用get接口
 * @param service 接口地址
 * @param params 参数，以{对象}形式
 * @returns {Promise<AxiosResponse<T>>}
 */
const get = (service = '', params = null) => {
  const url = params ? `${URL_PREFIX}${service}?${QueryString.stringify(params)}` : `${URL_PREFIX}${service}`;
  return GET(url).then((result) => result.data);
};

/**
 * 仅使用dispatch
 * @param type
 * @param data
 * @returns {Function}
 */
const dispatchOnly = (type = '', data = null) => (dispatch) => {
  dispatch({
    type: type.SUCCESS,
    data,
  });
};

export { getDispatch, get, dispatchOnly };
